summaryrefslogtreecommitdiffstats
path: root/kwin/clients/default/kdedefault.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kwin/clients/default/kdedefault.cpp')
-rw-r--r--kwin/clients/default/kdedefault.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/kwin/clients/default/kdedefault.cpp b/kwin/clients/default/kdedefault.cpp
index d91ccf56b..f3b8fa2ba 100644
--- a/kwin/clients/default/kdedefault.cpp
+++ b/kwin/clients/default/kdedefault.cpp
@@ -240,7 +240,7 @@ unsigned long KDEDefaultHandler::readConfig( bool update )
|| new_useGradients != useGradients
|| new_titleHeight != normalTitleHeight
|| new_toolTitleHeight != toolTitleHeight )
- changed |= SettingColors; // just recreate the pixmaps and repaint
+ changed |= SettingColors; // just recreate the pixmaps and tqrepaint
}
showGrabBar = new_showGrabBar;
@@ -328,7 +328,7 @@ void KDEDefaultHandler::createPixmaps()
TQPainter p;
// Active pins
- g = options()->colorGroup( ColorButtonBg, true );
+ g = options()->tqcolorGroup( ColorButtonBg, true );
pinUpPix = new KPixmap();
pinUpPix->resize(16, 16);
p.begin( pinUpPix );
@@ -346,7 +346,7 @@ void KDEDefaultHandler::createPixmaps()
pinDownPix->setMask( TQBitmap(16, 16, pindown_mask_bits, true) );
// Inactive pins
- g = options()->colorGroup( ColorButtonBg, false );
+ g = options()->tqcolorGroup( ColorButtonBg, false );
ipinUpPix = new KPixmap();
ipinUpPix->resize(16, 16);
p.begin( ipinUpPix );
@@ -404,25 +404,25 @@ void KDEDefaultHandler::createPixmaps()
irightBtnDownPix[false]->resize(toolTitleHeight, toolTitleHeight);
// Draw the button state pixmaps
- g = options()->colorGroup( ColorTitleBar, true );
+ g = options()->tqcolorGroup( ColorTitleBar, true );
drawButtonBackground( leftBtnUpPix[true], g, false );
drawButtonBackground( leftBtnDownPix[true], g, true );
drawButtonBackground( leftBtnUpPix[false], g, false );
drawButtonBackground( leftBtnDownPix[false], g, true );
- g = options()->colorGroup( ColorButtonBg, true );
+ g = options()->tqcolorGroup( ColorButtonBg, true );
drawButtonBackground( rightBtnUpPix[true], g, false );
drawButtonBackground( rightBtnDownPix[true], g, true );
drawButtonBackground( rightBtnUpPix[false], g, false );
drawButtonBackground( rightBtnDownPix[false], g, true );
- g = options()->colorGroup( ColorTitleBar, false );
+ g = options()->tqcolorGroup( ColorTitleBar, false );
drawButtonBackground( ileftBtnUpPix[true], g, false );
drawButtonBackground( ileftBtnDownPix[true], g, true );
drawButtonBackground( ileftBtnUpPix[false], g, false );
drawButtonBackground( ileftBtnDownPix[false], g, true );
- g = options()->colorGroup( ColorButtonBg, false );
+ g = options()->tqcolorGroup( ColorButtonBg, false );
drawButtonBackground( irightBtnUpPix[true], g, false );
drawButtonBackground( irightBtnDownPix[true], g, true );
drawButtonBackground( irightBtnUpPix[false], g, false );
@@ -676,7 +676,7 @@ void KDEDefaultButton::drawButton(TQPainter *p)
// otherwise we paint a menu button (with mini icon), or a sticky button.
if( deco ) {
// Select the appropriate button decoration color
- bool darkDeco = qGray( KDecoration::options()->color(
+ bool darkDeco = tqGray( KDecoration::options()->color(
isLeft() ? KDecoration::ColorTitleBar : KDecoration::ColorButtonBg,
active).rgb() ) > 127;
@@ -708,7 +708,7 @@ void KDEDefaultButton::drawButton(TQPainter *p)
// Smooth scale the pixmap for small titlebars
// This is slow, but we assume this isn't done too often
if ( width() < 16 ) {
- btnpix.convertFromImage(btnpix.convertToImage().smoothScale(12, 12));
+ btnpix.convertFromImage(TQImage(btnpix.convertToImage()).smoothScale(12, 12));
p->drawPixmap( 0, 0, btnpix );
}
else
@@ -720,7 +720,7 @@ void KDEDefaultButton::drawButton(TQPainter *p)
void KDEDefaultButton::enterEvent(TQEvent *e)
{
isMouseOver=true;
- repaint(false);
+ tqrepaint(false);
TQButton::enterEvent(e);
}
@@ -728,7 +728,7 @@ void KDEDefaultButton::enterEvent(TQEvent *e)
void KDEDefaultButton::leaveEvent(TQEvent *e)
{
isMouseOver=false;
- repaint(false);
+ tqrepaint(false);
TQButton::leaveEvent(e);
}
@@ -856,7 +856,7 @@ void KDEDefaultClient::init()
void KDEDefaultClient::reset( unsigned long changed)
{
- widget()->repaint();
+ widget()->tqrepaint();
KCommonDecoration::reset(changed);
}
@@ -909,7 +909,7 @@ void KDEDefaultClient::paintEvent( TQPaintEvent* )
p.drawRect(x,y,w,h);
// Draw part of the frame that is the titlebar color
- g = options()->colorGroup(ColorTitleBar, isActive());
+ g = options()->tqcolorGroup(ColorTitleBar, isActive());
p.setPen(g.light());
p.drawLine(x+1, y+1, rightOffset-1, y+1);
p.drawLine(x+1, y+1, x+1, leftFrameStart+borderWidth-4);
@@ -929,7 +929,7 @@ void KDEDefaultClient::paintEvent( TQPaintEvent* )
p.drawLine(x+borderWidth-2, y+titleHeight+3, x+borderWidth-2, leftFrameStart-2);
// Fill out the border edges
- g = options()->colorGroup(ColorFrame, isActive());
+ g = options()->tqcolorGroup(ColorFrame, isActive());
p.setPen(g.light());
p.drawLine(rightOffset, y+1, x2-1, y+1);
p.drawLine(x+1, leftFrameStart+borderWidth-3, x+1, y2-1);